#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 type-errors-pretty
version:              0.0.1.2
visibility:           public
id:                   type-errors-pretty-0.0.1.2-DLTPW4LdRNX6zo8opo6YIV
key:                  type-errors-pretty-0.0.1.2-DLTPW4LdRNX6zo8opo6YIV
license:              MPL-2.0
copyright:
    2019-2020 Dmitrii Kovanikov
    2020-2021 Kowainik

maintainer:
    Dmitrii Kovanikov <kovanikov@gmail.com>
    Kowainik <xrom.xkov@gmail.com>

author:               Dmitrii Kovanikov
homepage:             https://github.com/kowainik/type-errors-pretty
synopsis:             Combinators for writing pretty type errors easily
description:
    This library provides replacements for the @ErrorMessage@ constructors to
    write the text of custom error messages easily.

category:             Types, Type Errors
abi:                  4ff9edc45c7be41a12317cae64b3ce38
exposed:              True
exposed-modules:      Type.Errors.Pretty
import-dirs:          /usr/lib/ghc-9.6.6/site-local/type-errors-pretty-0.0.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/type-errors-pretty-0.0.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/type-errors-pretty-0.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-type-errors-pretty
hs-libraries:         HStype-errors-pretty-0.0.1.2-DLTPW4LdRNX6zo8opo6YIV
depends:              base-4.18.2.1
haddock-interfaces:
    /usr/share/doc/haskell-type-errors-pretty/html/type-errors-pretty.haddock

haddock-html:         /usr/share/doc/haskell-type-errors-pretty/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

